..
    This file is part of lazr.batchnavigator.

    lazr.batchnavigator is free software: you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License as
    published by the Free Software Foundation, version 3 of the License.

    lazr.batchnavigator is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
    License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with lazr.batchnavigator. If not, see
    <http://www.gnu.org/licenses/>.

============
Introduction
============

To run this project's tests, use `tox <https://tox.readthedocs.io/en/latest/>`.


Getting help
------------

If you find bugs in this package, you can report them here:

    https://launchpad.net/lazr.batchnavigator

If you want to discuss this package, join the team and mailing list here:

    https://launchpad.net/~lazr-users

or send a message to:

    lazr-users@lists.launchpad.net
